clearMessages static method
Clears all messages from the message stream for the device.
Implementation
static Future<void> clearMessages() async {
return _channel.invokeMethod('clearMessages');
}
Clears all messages from the message stream for the device.
static Future<void> clearMessages() async {
return _channel.invokeMethod('clearMessages');
}