model/attributes library

Classes

Attributes
A typed map of user attributes to be sent to Marigold via Sailthru.setAttributes.

Enums

MergeRules
Controls how Attributes are applied to the existing device attributes.