mergeRule property
Controls how these attributes are applied to the existing device attributes. Defaults to MergeRules.update.
Implementation
MergeRules mergeRule = MergeRules.update;
Controls how these attributes are applied to the existing device attributes. Defaults to MergeRules.update.
MergeRules mergeRule = MergeRules.update;