messageId property
The Sailthru message ID to attribute this purchase to. Required for revenue data to be matched to email sends in Sailthru.
Implementation
String? messageId;
The Sailthru message ID to attribute this purchase to. Required for revenue data to be matched to email sends in Sailthru.
String? messageId;