PurchaseAdjustment class
A positive or negative price adjustment applied to a Purchase (e.g. a discount or shipping cost).
Constructors
- PurchaseAdjustment(String title, int price)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- price → int
-
The adjustment amount in cents. Use a negative value for discounts.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
A short, user-readable name for the adjustment.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited