PurchaseItem class

Represents a single item within a Purchase.

Constructors

PurchaseItem(int quantity, String title, int price, String id, String url)

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Your unique identifier for the item (e.g. SKU).
final
price int
The price of a single unit of this item, in cents (e.g. $10.99 = 1099).
final
quantity int
The quantity of the item purchased.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<String>?
Optional tags applicable to the item.
getter/setter pair
title String
A short, user-readable name for the item.
final
url String
The URL of the item's page. Domain and scheme are case-sensitive.
final
vars Map<String, dynamic>?
Optional custom key-value pairs to attach to the item.
getter/setter pair

Methods

addFullImage(String fullUrl) → void
Sets the URL for the full-sized item image.
addThumbImage(String thumbUrl) → void
Sets the URL for the thumbnail item image.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited