MessageStream class
Provides access to the Marigold in-app message stream, including retrieving, displaying, and managing messages and their read state.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
clearMessages(
) → Future< void> - Clears all messages from the message stream for the device.
-
dismissMessageDetail(
) → Future< void> - Dismisses the message detail view.
-
getMessages(
) → Future< List< Message> > - Retrieves all messages visible for this device.
-
getUnreadCount(
) → Future< int> - Returns the total number of unread messages in the message stream.
-
markMessageAsRead(
Message message) → Future< void> -
Marks the given
messageas read. -
presentMessageDetail(
Message message) → Future< void> -
Presents the full-screen message detail view for the given
message. -
registerMessageImpression(
Message message, ImpressionType impressionType) → Future< void> -
Registers an impression for the given
messagewith the specifiedimpressionType. -
removeMessage(
Message message) → Future< void> -
Removes the given
messagefrom the device's message stream. -
testOverrideChannel(
MethodChannel channel) → void