Attributes class
A typed map of user attributes to be sent to Marigold via
Sailthru.setAttributes.
Set the mergeRule to control whether the attributes are merged with or replace the existing attributes on the device.
Constructors
Properties
-
attributeMap
↔ Map<
String, Map< String, dynamic> > -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- mergeRule ↔ MergeRules
-
Controls how these attributes are applied to the existing device
attributes. Defaults to MergeRules.update.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setBoolean(
String key, bool value) → void -
Sets a boolean value for
key. -
setDate(
String key, DateTime value) → void -
Sets a date value for
key. -
setDateArray(
String key, List< DateTime> value) → void -
Sets a list of date values for
key. -
setFloat(
String key, double value) → void -
Sets a float value for
key. -
setFloatArray(
String key, List< double> value) → void -
Sets a list of float values for
key. -
setInteger(
String key, int value) → void -
Sets an integer value for
key. -
setIntegerArray(
String key, List< int> value) → void -
Sets a list of integer values for
key. -
setString(
String key, String value) → void -
Sets a string value for
key. -
setStringArray(
String key, List< String> value) → void -
Sets a list of string values for
key. -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited