Message class

Represents a Marigold in-app message retrieved from the message stream.

Constructors

Message.fromMap(Map<Object?, Object?> messageMap)
factory

Properties

attributes Map<String, String?>?
Custom key-value pairs set on the message at authoring time.
final
contentUrl String?
The URL attached to the message.
final
createdAt DateTime
The time at which the message was created.
final
hashCode int
The hash code for this object.
no setterinherited
htmlText String?
The body of the message rendered as HTML.
final
id String
The unique ID of the message.
final
imageUrl String?
The URL of the image attached to the message.
final
isRead bool
Whether the message has been marked as read.
final
isShareable bool
Whether this message has sharing enabled.
final
mediaUrl String?
The URL of the video attached to the message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
The plain-text body of the message.
final
title String
The title of the message.
final
type String?
The type of the message (e.g. text, image, link, video).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited