Purchase class
Represents a purchase to be logged with the Marigold platform via
Sailthru.logPurchase or Sailthru.logAbandonedCart.
Constructors
-
Purchase(List<
PurchaseItem> purchaseItems)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- messageId ↔ String?
-
The Sailthru message ID to attribute this purchase to. Required for
revenue data to be matched to email sends in Sailthru.
getter/setter pair
-
purchaseAdjustments
↔ List<
PurchaseAdjustment> ? -
Optional price adjustments to apply to the order (e.g. discounts,
shipping costs).
getter/setter pair
-
purchaseItems
↔ List<
PurchaseItem> -
The items included in this purchase.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
vars
↔ Map<
String, dynamic> ? -
Optional custom variables to attach to the order.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited